@@ -11,7 +11,7 @@ class ProofContext:
     """Helper class which accumulates successful proof steps and keeps track of stats during the proof process"""
 
     max_proofs: Optional[int]
-    scored_proof_steps: list[tuple[float, int, ProofStep, ProofStats]]
+    scored_leaf_proof_steps: list[tuple[float, int, ProofStep, ProofStats]]
     min_similarity_threshold: float
     stats: ProofStats
     seen_resolvents_hash: dict[int, tuple[int, float]]
@@ -26,7 +26,7 @@ class ProofContext:
         self.stats = ProofStats()
         self.min_similarity_threshold = initial_min_similarity_threshold
         self.max_proofs = max_proofs
-        self.scored_proof_steps = []
+        self.scored_leaf_proof_steps = []
         self.seen_resolvents_hash = {}
         self.skip_seen_resolvents = skip_seen_resolvents
 
@@ -34,7 +34,7 @@ class ProofContext:
         """Add a leaf proof step to the accumulator"""
 
         # make sure to clone the stats before appending, since the stats will continue to get mutated after this
-        self.scored_proof_steps.append(
+        self.scored_leaf_proof_steps.append(
             (
                 proof_step.running_similarity,
                 proof_step.depth,
@@ -42,19 +42,23 @@ class ProofContext:
                 copy(self.stats),
             )
         )
-        self.scored_proof_steps.sort(key=lambda x: (x[0], -1 * x[1]), reverse=True)
-        if self.max_proofs and len(self.scored_proof_steps) > self.max_proofs:
+        self.scored_leaf_proof_steps.sort(key=lambda x: (x[0], -1 * x[1]), reverse=True)
+        if self.max_proofs and len(self.scored_leaf_proof_steps) > self.max_proofs:
             # Remove the proof step with the lowest similarity
-            self.scored_proof_steps.pop()
+            self.scored_leaf_proof_steps.pop()
             self.stats.discarded_proofs += 1
             # Update the minimum similarity threshold to the new lowest similarity
-            self.min_similarity_threshold = self.scored_proof_steps[-1][0]
+            self.min_similarity_threshold = self.scored_leaf_proof_steps[-1][0]
 
     def leaf_proof_steps_with_stats(self) -> list[tuple[ProofStep, ProofStats]]:
         return [
-            (proof_step, stats) for _, _, proof_step, stats in self.scored_proof_steps
+            (proof_step, stats)
+            for _, _, proof_step, stats in self.scored_leaf_proof_steps
         ]
 
+    def total_leaf_proofs(self) -> int:
+        return len(self.scored_leaf_proof_steps)
+
     def check_resolvent(
         self,
         proof_step: ProofStep,
